==> 2.4.11.tar.gz: cloudlog/application/language/swedish/general_words_lang.php <==
<?php

defined('BASEPATH') OR exit('No direct script access allowed');

$lang['error_no_active_station_profile'] = 'OBS! Du behöver ange en aktiv station location.';

$lang['notice_turn_the_radio_on'] = 'Inga QSOn idag - dags att slå på radion!';

$lang['general_word_important'] = 'Viktigt';
$lang['general_word_warning'] = 'Warning';
$lang['general_word_danger'] = 'DANGER';
$lang['general_word_maintenance'] = 'Maintenance';
$lang['general_word_info'] = 'Info';
$lang['general_word_choose_file'] = 'Välj fil';
$lang['general_word_next'] = 'Next';
$lang['general_word_previous'] = 'Previous';
$lang['general_word_enabled'] = "Enabled";
$lang['general_word_disabled'] = "Disabled";
$lang['general_word_export'] = "Export";
$lang['general_word_import'] = "Import";

$lang['general_word_date'] = 'Datum';
$lang['general_word_time'] = 'Tid';
$lang['general_word_datetime'] = 'Datum/Tid';
$lang['general_word_none'] = 'Ingen';
$lang['general_word_name'] = 'Namn';
$lang['general_word_location'] = 'QTH';
$lang['general_word_comment'] = 'Notering';
$lang['general_word_general'] = 'Allmänt';
$lang['general_word_satellite'] = 'Satellit';
$lang['general_word_satellite_short'] = 'Sat';
$lang['general_word_notes'] = 'Anteckningar';
$lang['general_word_country'] = 'Land';
$lang['general_word_city'] = 'City';

$lang['general_word_total'] = 'Totalt';
$lang['general_word_year'] = 'I år';
$lang['general_word_month'] = 'Denna månad';

$lang['general_word_worked'] = 'Körda';
$lang['general_word_confirmed'] = 'Bekräftade';
$lang['general_word_needed'] = 'Behövs';

$lang['general_word_all'] = 'All';
$lang['general_word_no'] = 'Nej';
$lang['general_word_yes'] = 'Ja';
$lang['general_word_method'] = 'Metod';

$lang['general_word_sent'] = 'Skickad';
$lang['general_word_received'] = 'Mottagen';
$lang['general_word_requested'] = 'Begärd';
$lang['general_word_queued'] = 'Köad';
$lang['general_word_invalid_ignore'] = 'Invalid (Ignore)';
$lang['general_word_qslcard'] = 'QSL-kort';
$lang['general_word_qslcard_management'] = 'QSL Management';
$lang['general_word_qslcards'] = 'QSL-kort';
$lang['general_word_qslcard_direct'] = 'Direkt';
$lang['general_word_qslcard_bureau'] = 'Byrå';
$lang['general_word_qslcard_electronic'] = 'Elektronisk';
$lang['general_word_qslcard_manager'] = 'Manager';
$lang['general_word_qslcard_via'] = 'Via';
$lang['general_word_eqslcard'] = 'eQSL Card';
$lang['general_word_eqslcards'] = 'eQSL Cards';
$lang['general_word_lotw'] = 'Logbook of the World';
$lang['general_word_lotw_short'] = 'LoTW';

$lang['general_word_details'] = 'Details';
$lang['general_word_qso_data'] = 'QSO Data';

$lang['general_edit_qso'] = 'Redigera QSO';
$lang['general_mark_qsl_rx_bureau'] = 'Ange QSL mottagen (Byrå)';
$lang['general_mark_qsl_rx_direct'] = 'Ange QSL mottagen (Direkt)';
$lang['general_mark_qsl_rx_electronic'] = 'Ange QSL mottagen (Elektronisk)';
$lang['general_mark_qsl_tx_bureau'] = 'Ange QSL skickad (Byrå)';
$lang['general_mark_qsl_tx_direct'] = 'Ange QSL skickad (Direkt)';
$lang['general_mark_qsl_requested'] = 'Ange QSL Karta Begärda';
$lang['general_mark_qsl_requested_bureau'] = 'Ange QSL Karta Begärda (Byrå)';
$lang['general_mark_qsl_requested_direct'] = 'Ange QSL Karta Begärda (Direkt)';
$lang['general_mark_qsl_not_required'] = 'Ange QSL Karta Inte Nödvändig';

$lang['general_delete_qso'] = 'Radera QSO';
$lang['general_more_qso'] = 'More QSOs';

$lang['general_lookup_qrz'] = 'Lookup on QRZ.com';
$lang['general_lookup_hamqth'] = 'Lookup on HamQTH';

$lang['general_total_distance'] = 'Totalt avstånd';

// PHP Upload Warning
$lang['gen_max_file_upload_size'] = 'Maximum file upload size is ';

// Cloudlog Terms
$lang['cloudlog_station_profile'] = 'Stationsplats';

// ham radio terms
$lang['gen_hamradio_cq'] = "CQ";
$lang['gen_hamradio_qso'] = 'QSO';
$lang['gen_hamradio_station'] = 'Station';

$lang['gen_hamradio_call'] = 'Signal';
$lang['gen_hamradio_callsign'] = 'Signal';
$lang['gen_hamradio_de'] = 'De';
$lang['gen_hamradio_dx'] = 'Dx';
$lang['gen_hamradio_mode'] = 'Mode';
$lang['gen_hamradio_rst_sent'] = 'Skickat';
$lang['gen_hamradio_rst_rcvd'] = 'Mottagen\'d';
$lang['gen_hamradio_band'] = 'Band';
$lang['gen_hamradio_bandgroup'] = "Bandgroup";
$lang['gen_hamradio_band_rx'] = 'Band (RX)';
$lang['gen_hamradio_frequency'] = 'Frekvens';
$lang['gen_hamradio_frequency_rx'] = 'Frekvens (RX)';
$lang['gen_hamradio_radio'] = 'Radio';
$lang['gen_hamradio_rsts'] = 'RST (S)';
$lang['gen_hamradio_rstr'] = 'RST (R)';
$lang['gen_hamradio_refs'] = 'Refs';
$lang['gen_hamradio_myrefs'] = 'My Refs';
$lang['gen_hamradio_exchange_sent_short'] = 'Exch (S)';
$lang['gen_hamradio_exchange_rcvd_short'] = 'Exch (R)';
$lang['gen_hamradio_qsl'] = 'QSL';
$lang['gen_hamradio_qslvia'] = 'QSL via';
$lang['gen_hamradio_qslmsg'] = 'QSL Msg';
$lang['gen_hamradio_locator'] = 'Lokator';
$lang['gen_hamradio_transmit_power'] = 'Effekt (W)';
$lang['gen_hamradio_propagation_mode'] = 'Propagation Mode';

$lang['gen_hamradio_satellite_name'] = 'Satellitnamn';
$lang['gen_hamradio_satellite_mode'] = 'Satellite-mode';

$lang['gen_hamradio_logbook'] = 'Loggbok';

$lang['gen_hamradio_zones'] = 'Zones';
$lang['gen_hamradio_cq_zone'] = 'CQ Zone';
$lang['gen_hamradio_itu_zone'] = 'ITU Zone';
$lang['gen_hamradio_dxcc'] = 'DXCC';
$lang['gen_hamradio_deleted_dxcc'] = 'Struket DXCC';
$lang['gen_hamradio_continent'] = 'Kontinent';
$lang['gen_hamradio_usa_state'] = 'USA State';
$lang['gen_hamradio_county_reference'] = 'USA County';
$lang['gen_hamradio_iota_reference'] = 'IOTA Reference';
$lang['gen_hamradio_sota_reference'] = 'SOTA Reference';
$lang['gen_hamradio_wwff_reference'] = 'WWFF Reference';
$lang['gen_hamradio_pota_reference'] = 'POTA Reference';
$lang['gen_hamradio_dok'] = 'DOK';
$lang['gen_hamradio_state'] = 'State';
$lang['gen_hamradio_iota'] = 'IOTA';
$lang['gen_hamradio_sota'] = 'SOTA';
$lang['gen_hamradio_wwff'] = 'WWFF';
$lang['gen_hamradio_pota'] = 'POTA';
$lang['gen_hamradio_gridsquare'] = 'Lokator/Gridsquare';
$lang['gen_hamradio_get_gridsquare'] = 'Get Gridsquare';
$lang['gen_hamradio_distance'] = 'Distance';
$lang['gen_hamradio_operator'] = 'Operatör';

$lang['gen_hamradio_sig'] = 'Sig';
$lang['gen_hamradio_sig_info'] = 'Sig Info';

// Find your CQ/ITU Zone
$lang['gen_find_zone_cq_part1'] = "If you don't know your CQ Zone then ";
$lang['gen_find_zone_itu_part1'] = "If you don't know your ITU Zone then ";
$lang['gen_find_zone_part2'] = 'click here';
$lang['gen_find_zone_part3'] = ' to find it!';

// Dashboard Words
$lang['dashboard_you_have_had'] = 'Du har kört';
$lang['dashboard_qsos_today'] = 'QSOs idag!';
$lang['dashboard_qso_breakdown'] = 'QSOs Breakdown';
$lang['dashboard_countries_breakdown'] = 'Länder Breakdown';
$lang['gen_to_date'] = 'To date';

$lang['gen_from_date'] = 'Från datum';

$lang['gen_this_qso_was_confirmed_on'] = 'Detta QSO blev konfirmerat';

$lang['error_no_logbook_found'] = 'Ingen loggbok hittades. Du måste konfigurera en loggbok under Station Logbooks. Gör det här:';

$lang['copy_to_clipboard'] = 'Kopiera till clipboard';

$lang['africa'] = 'Afrika';
$lang['antarctica'] = 'Antarktis';
$lang['asia'] = 'Asien';
$lang['europe'] = 'Europa';
$lang['northamerica'] = 'Nordamerika';
$lang['oceania'] = 'Oceanien';
$lang['southamerica'] = 'Sydamerika';

$lang['gen_band_selection'] = 'Band val';
$lang['general_word_today'] = 'Today';

==> 2.5.2.tar.gz: cloudlog/application/language/swedish/general_words_lang.php <==
<<<<<<< HEAD
<?php

defined('BASEPATH') OR exit('No direct script access allowed');

$lang['error_no_active_station_profile'] = 'OBS! Du behöver ange en aktiv station location.';

$lang['notice_turn_the_radio_on'] = 'Inga QSOn idag - dags att slå på radion!';

$lang['general_word_important'] = 'Viktigt';
$lang['general_word_warning'] = 'Warning';
$lang['general_word_danger'] = 'DANGER';
$lang['general_word_maintenance'] = 'Maintenance';
$lang['general_word_info'] = 'Info';
$lang['general_word_choose_file'] = 'Välj fil';
$lang['general_word_next'] = 'Next';
$lang['general_word_previous'] = 'Previous';

$lang['general_word_cancel'] = "Cancel";
$lang['general_word_ok'] = "OK";
$lang['general_word_attention'] = "Attention";
$lang['general_word_enabled'] = "Enabled";
$lang['general_word_disabled'] = "Disabled";
$lang['general_word_count'] = "Count";
$lang['general_word_filtering_on'] = "Filtering on";
$lang['general_word_export'] = "Export";
$lang['general_word_import'] = "Import";
$lang['general_word_startdate'] = "Start Date";
$lang['general_word_enddate'] = "End Date";

$lang['general_word_date'] = 'Datum';
$lang['general_word_time'] = 'Tid';
$lang['general_word_time_on'] = 'Time on';
$lang['general_word_time_off'] = 'Time off';
$lang['general_word_datetime'] = 'Datum/Tid';
$lang['general_word_none'] = 'Ingen';
$lang['general_word_name'] = 'Namn';
$lang['general_word_location'] = 'QTH';
$lang['general_word_comment'] = 'Notering';
$lang['general_word_general'] = 'Allmänt';
$lang['general_word_satellite'] = 'Satellit';
$lang['general_word_satellite_short'] = 'Sat';
$lang['general_word_notes'] = 'Anteckningar';
$lang['general_word_country'] = 'Land';
$lang['general_word_city'] = 'City';

$lang['general_word_total'] = 'Totalt';
$lang['general_word_year'] = 'I år';
$lang['general_word_month'] = 'Denna månad';

$lang['general_word_colors'] = "Colors";
$lang['general_word_light'] = "Light/Laser";
$lang['general_word_worked'] = 'Körda';
$lang['general_word_worked_not_confirmed'] = "Worked not confirmed";
$lang['general_word_confirmation'] = "Confirmation";
$lang['general_word_not_worked'] = "Not worked";
$lang['general_word_confirmed'] = 'Bekräftade';
$lang['general_word_needed'] = 'Behövs';
$lang['general_word_all'] = 'All';
$lang['general_word_no'] = 'Nej';
$lang['general_word_yes'] = 'Ja';
$lang['general_word_method'] = 'Metod';

$lang['general_word_sent'] = 'Skickad';
$lang['general_word_received'] = 'Mottagen';
$lang['general_word_requested'] = 'Begärd';
$lang['general_word_queued'] = 'Köad';
$lang['general_word_table'] = "Table";
$lang['general_word_invalid_ignore'] = 'Invalid (Ignore)';
$lang['general_word_qslcard'] = 'QSL-kort';
$lang['general_word_qslcard_management'] = 'QSL Management';
$lang['general_word_qslcards'] = 'QSL-kort';
$lang['general_word_qslcard_direct'] = 'Direkt';
$lang['general_word_qslcard_bureau'] = 'Byrå';
$lang['general_word_qslcard_electronic'] = 'Elektronisk';
$lang['general_word_qslcard_manager'] = 'Manager';
$lang['general_word_qslcard_via'] = 'Via';
$lang['general_word_eqslcard'] = 'eQSL Card';
$lang['general_word_eqslcards'] = 'eQSL Cards';
$lang['general_word_lotw'] = 'Logbook of the World';
$lang['general_word_lotw_short'] = 'LoTW';

$lang['general_word_details'] = 'Details';
$lang['general_word_qso_data'] = 'QSO Data';

$lang['general_edit_qso'] = 'Redigera QSO';
$lang['general_mark_qsl_rx_bureau'] = 'Ange QSL mottagen (Byrå)';
$lang['general_mark_qsl_rx_direct'] = 'Ange QSL mottagen (Direkt)';
$lang['general_mark_qsl_rx_electronic'] = 'Ange QSL mottagen (Elektronisk)';
$lang['general_mark_qsl_tx_bureau'] = 'Ange QSL skickad (Byrå)';
$lang['general_mark_qsl_tx_direct'] = 'Ange QSL skickad (Direkt)';
$lang['general_mark_qsl_requested'] = 'Ange QSL Karta Begärda';
$lang['general_mark_qsl_requested_bureau'] = 'Ange QSL Karta Begärda (Byrå)';
$lang['general_mark_qsl_requested_direct'] = 'Ange QSL Karta Begärda (Direkt)';
$lang['general_mark_qsl_not_required'] = 'Ange QSL Karta Inte Nödvändig';

$lang['general_delete_qso'] = 'Radera QSO';
$lang['general_more_qso'] = 'More QSOs';

$lang['general_lookup_qrz'] = 'Lookup on QRZ.com';
$lang['general_lookup_hamqth'] = 'Lookup on HamQTH';

$lang['general_total_distance'] = 'Totalt avstånd';

// PHP Upload Warning
$lang['gen_max_file_upload_size'] = 'Maximum file upload size is ';

// Cloudlog Terms
$lang['cloudlog_station_profile'] = 'Stationsplats';

// ham radio terms
$lang['gen_hamradio_cq'] = "CQ";
$lang['gen_hamradio_qso'] = 'QSO';
$lang['gen_hamradio_station'] = 'Station';

$lang['gen_hamradio_call'] = 'Signal';
$lang['gen_hamradio_prefix'] = "Prefix";
$lang['gen_hamradio_suffix'] = "Suffix";
$lang['gen_hamradio_callsign'] = 'Signal';
$lang['gen_hamradio_de'] = 'De';
$lang['gen_hamradio_dx'] = 'Dx';
$lang['gen_hamradio_mode'] = 'Mode';
$lang['gen_hamradio_rst_sent'] = 'Skickat';
$lang['gen_hamradio_rst_rcvd'] = 'Mottagen\'d';
$lang['gen_hamradio_band'] = 'Band';
$lang['gen_hamradio_bandgroup'] = "Bandgroup";
$lang['gen_hamradio_band_rx'] = 'Band (RX)';
$lang['gen_hamradio_frequency'] = 'Frekvens';
$lang['gen_hamradio_frequency_rx'] = 'Frekvens (RX)';
$lang['gen_hamradio_radio'] = 'Radio';
$lang['gen_hamradio_rsts'] = 'RST (S)';
$lang['gen_hamradio_rstr'] = 'RST (R)';
$lang['gen_hamradio_refs'] = 'Refs';
$lang['gen_hamradio_myrefs'] = 'My Refs';
$lang['gen_hamradio_exchange_sent_short'] = 'Exch (S)';
$lang['gen_hamradio_exchange_rcvd_short'] = 'Exch (R)';
$lang['gen_hamradio_qsl'] = 'QSL';
$lang['gen_hamradio_qsltype'] = "QSL Type";
$lang['gen_hamradio_qslvia'] = 'QSL via';
$lang['gen_hamradio_qslmsg'] = 'QSL Msg';
$lang['gen_hamradio_locator'] = 'Lokator';
$lang['gen_hamradio_transmit_power'] = 'Effekt (W)';
$lang['gen_hamradio_propagation_mode'] = 'Propagation Mode';

$lang['gen_hamradio_satellite_name'] = 'Satellitnamn';
$lang['gen_hamradio_satellite_mode'] = 'Satellite-mode';

$lang['gen_hamradio_award'] = "Award";
$lang['gen_hamradio_logbook'] = 'Loggbok';

$lang['gen_hamradio_zones'] = 'Zones';
$lang['gen_hamradio_cq_zone'] = 'CQ Zone';
$lang['gen_hamradio_itu_zone'] = 'ITU Zone';
$lang['gen_hamradio_dxcc'] = 'DXCC';
$lang['gen_hamradio_deleted_dxcc'] = 'Struket DXCC';
$lang['gen_hamradio_continent'] = 'Kontinent';
$lang['gen_hamradio_usa_state'] = 'USA State';
$lang['gen_hamradio_county_reference'] = 'USA County';
$lang['gen_hamradio_iota_reference'] = 'IOTA Reference';
$lang['gen_hamradio_sota_reference'] = 'SOTA Reference';
$lang['gen_hamradio_wwff_reference'] = 'WWFF Reference';
$lang['gen_hamradio_pota_reference'] = 'POTA Reference';
$lang['gen_hamradio_dok'] = 'DOK';
$lang['gen_hamradio_state'] = 'State';
$lang['gen_hamradio_iota'] = 'IOTA';
$lang['gen_hamradio_sota'] = 'SOTA';
$lang['gen_hamradio_wwff'] = 'WWFF';
$lang['gen_hamradio_pota'] = 'POTA';
$lang['gen_hamradio_gridsquare'] = 'Lokator/Gridsquare';
$lang['gen_hamradio_latitude'] = "Latitude";
$lang['gen_hamradio_longitude'] = "Longitude";
$lang['gen_hamradio_bearing'] = "Bearing";
$lang['gen_hamradio_get_gridsquare'] = 'Get Gridsquare';
$lang['gen_hamradio_distance'] = 'Distance';
$lang['gen_hamradio_operator'] = 'Operatör';

$lang['gen_hamradio_sig'] = 'Sig';
$lang['gen_hamradio_sig_info'] = 'Sig Info';

// Find your CQ/ITU Zone
$lang['gen_find_zone_cq_part1'] = "If you don't know your CQ Zone then";
$lang['gen_find_zone_itu_part1'] = "If you don't know your ITU Zone then";
$lang['gen_find_zone_part2'] = "click here";
$lang['gen_find_zone_part3'] = "to find it!";

// Dashboard Words
$lang['dashboard_you_have_had'] = 'Du har kört';
$lang['dashboard_qsos_today'] = 'QSOs idag!';
$lang['dashboard_qso_breakdown'] = 'QSOs Breakdown';
$lang['dashboard_countries_breakdown'] = 'Länder Breakdown';
$lang['gen_to_date'] = 'To date';

$lang['gen_from_date'] = 'Från datum';

$lang['gen_this_qso_was_confirmed_on'] = 'Detta QSO blev konfirmerat';

$lang['error_no_logbook_found'] = 'Ingen loggbok hittades. Du måste konfigurera en loggbok under Station Logbooks. Gör det här:';

$lang['copy_to_clipboard'] = 'Kopiera till clipboard';

$lang['africa'] = 'Afrika';
$lang['antarctica'] = 'Antarktis';
$lang['asia'] = 'Asien';
$lang['europe'] = 'Europa';
$lang['northamerica'] = 'Nordamerika';
$lang['oceania'] = 'Oceanien';
$lang['southamerica'] = 'Sydamerika';

$lang['gen_band_selection'] = 'Band val';
$lang['general_word_today'] = 'Today';
                             
$lang['dashboard_php_version_warning'] = 'You need to upgrade your PHP version. Minimum version is 7.4. Your version is';
$lang['dashboard_country_files_warning'] = 'You need to update country files! Go <a href="'.site_url('update').'">here</a> to do it!';
$lang['dashboard_locations_warning'] = 'You have no station locations. Go <a href="'. site_url('station') . '">here</a> to create it!';
$lang['dashboard_logbooks_warning'] = 'You have no station logbook. Go <a href="'. site_url('logbooks') . '">here</a> to create it!';

$lang['hams_at_no_activations_found'] = 'No upcoming activations found. Please check back later.';
